import sys
import glob
import errno
import time
import os
from subprocess import check_output
import queue
import sounddevice as sd
import soundfile as sf
import _thread  

pathy = input("Enter the path to the datasets/audio files directory: ")
name = input("what is your name?    ")
t0 = int(input("Your desired Recording time in seconds:    "))
smr = int(input("sampling rate; 16000 or 42000 or 48000 or 96000 Hz:    "))
bt=int(input("bit depth; 8 or 16 or 24 or 32 bit:    "))

pa00=pathy+"/"+"dataset"+"/"+"audioFiles"+"/"
pa0=pathy+"/"+name+".wav"
pa1=pathy+"/"+"dataset"+"/"+"datanewchi22.csv"
pa2=pathy+"/"+"dataset"+"/"+"stats.csv"
pa3=pathy+"/"+"dataset"+"/"+"datacorrP.csv"
pa4=pathy+"/"+"dataset"+"/"+"datanewchi.csv"
pa5=pathy+"/"+"dataset"+"/"+"datanewchi33.csv"
pa6=pathy+"/"+"dataset"+"/"+"datanewchi33.csv"
pa7=pathy+"/"+"dataset"+"/"+"datanewchi44.csv"
pa8=pathy+"/"+"dataset"+"/"+"essen"+"/"+"MLTRNL.praat"
pa9=pathy+"/"+"dataset"+"/"+"essen"+"/"+"myspsolution.praat"

rere=pa0

RECORD_TIME = t0

def countdown(p,q,w):
    i=p
    j=q
    z=w
    k=0
    while True:
        if(j==-1):
            j=59
            i -=1
        if(j > 9):  
            print(str(k)+str(i)+ " : " +str(j), "\t", end="\r")
        else:
            print(str(k)+str(i)+" : " + str(k)+str(j), "\t", end="\r")
        time.sleep(1)
        j -= 1
        if(i==0 and j==-1):
            break
    if(i==0 and j==-1):
        if z==0:
            huf="Recording start!"
            print(huf)
        if z==1:
            huf="Time up!"
        # time.sleep(1)

print("===========================================")
print("HOLD ON!! get ready, 5 seconds to go!")
print("===========================================")
countdown(0,5,0) #countdown(min,sec)	


q = queue.Queue()
rec_start = int(time.time())

dev_info = sd.query_devices(2, 'input')
# samplerate = int(dev_info['default_samplerate'])
samplerate = smr

def data_callback(input_data, frames, time, status):
    if status:
        print(status, file=sys.stderr)
    q.put(input_data.copy())

with sf.SoundFile(rere, mode='x', samplerate=samplerate, channels=2) as file:
    with sd.InputStream(samplerate=samplerate, device=2, channels=2, callback=data_callback,blocksize=20500):
        rec_time = int(time.time()) - rec_start
        _thread.start_new_thread(countdown,(0,t0,1))
        while rec_time <= RECORD_TIME:
            file.write(q.get())
            rec_time = int(time.time()) - rec_start
print(" ")
print("===========================================")
input("Recording over!! press any key to exit")



from setuptools import setup

long_description="""My-Voice-Recorder is a convenient and simple python package that can
be used right in your machine. It allows you to record your voice using a microphone 
and save it as an wav file. 

My-Voice-Recorder was originally designed as a voice recorder for acoustic and language 
research or creative endeavors. It was tested for our Automatic language identification 
package and has a flexible adjustable and simple features for manual control which make 
it more adaptable for specific needs.  
These features not only make the device easier to use in an original environment, they 
also help for optimum file storage opportunities.

My-Voice-Recorder records in a wide range of quality such as CD-quality 16 or 24-bit 
linear PCM or other formats and automatically detect your machine's microphones. 
These are adjustable for varied stereo depth depending on your recording needs. It 
could support multi-track recording, all of which are great features for creative 
projects, as they allow for more control over the audio layers. 
The main downside to My-Voice-Recorder is that it does not include voice activation or 
dead air removal.

Adding an external microphone is the single most significant way to improve the quality
of the sound your machine captures. To give the voice recordings top-level audio, you'll 
need to get a standard mic.

MY-Voice-Recorder works with USB better though it is not a must. While the microphone quality 
usually serves as a good indicator of recorded voice quality, a few mic factors have an 
impact. Checking the mic frequency response (the range of sounds it can hear) and sampling rate.

=============
Installation
=============
My-Voice-Recorder can be installed like any other Python library, using (a recent version of) the
Python package manager pip, on Linux, macOS, and Windows:

------------------pip install myVOCRec
				
or, to update your installed version to the latest release:
------------------- pip install -u myVOCRec	---------------------------------

Recording files must be 25 sec. or longer of audio and in *.wav PCM/LPCM format, recorded at 48 kHz 
sample frame and 24-32 bits of resolution or AIFF, AIFF-C, FLAC: must be native FLAC format; 
OGG-FLAC is not supported.

please check out https://github.com/Shahabks/my-voice-recorder   

myVOCRec was developed by MYOLUTION Lab in Japan. It is being used internally where the quality of 
utterances is crucial for our Voice Recognition and Acoustic & Language modeling Project in the Lab. 
We plan to enrich the quality of myVOCRec by adding more advanced functions."""
	
	
setup(name='myVOCRec',
      version='1',
      description='Capturing Microphone Data into an Audio File',
	  long_description=long_description,
	  url='https://github.com/Shahabks/myspokenlanguageid',
      author='Shahab Sabahi',
      author_email='sabahi.s@mysol-gc.jp',
      license='MIT',
      classifiers=[
		'Intended Audience :: Developers',
		'Intended Audience :: Science/Research',
		'Programming Language :: Python',
		'Programming Language :: Python :: 3.7',
		],
	  keywords='speech signal processing , Natural Language Processing and Understanding , Voice-Recorder',
	  install_requires=[
		'sounddevice>=0.3.12',
		'SoundFile>=0.10.2',
		],
	  packages=['myVOCRec'],
      zip_safe=False)
	  
